@@ -1,6 +1,6 @@
 package MARC::Moose::Field::Std;
 # ABSTRACT: Standard Marc Field (tag >= 010)
-$MARC::Moose::Field::Std::VERSION = '1.0.30';
+$MARC::Moose::Field::Std::VERSION = '1.0.31';
 use Moose;
 
 extends 'MARC::Moose::Field';
@@ -26,7 +26,7 @@ override 'clone' => sub {
     my ($self, $tag) = @_;
     my $field = MARC::Moose::Field::Std->new( tag => $self->tag );
     $field->tag($tag) if $tag;
-    $field->subf( [ map { $_ } @{$self->subf} ] );
+    $field->subf( [ map { [ $_->[0] => $_->[1] ] } @{$self->subf} ] );
     return $field;
 };
 
@@ -61,7 +61,7 @@ MARC::Moose::Field::Std - Standard Marc Field (tag >= 010)
 
 =head1 VERSION
 
-version 1.0.30
+version 1.0.31
 
 =head1 ATTRIBUTES
 
